@@ -2,7 +2,6 @@
 #
 # SPDX-License-Identifier: GPL-3.0-only
 
-from typing import Any
 from typing import TextIO
 
 import cProfile
@@ -92,8 +91,8 @@ class CoreApplication(ged.EventHelper):
         app.cert_store = CertificateStore()
         app.task_manager = TaskManager()
 
-        from gajim.common.call_manager import CallManager
-        app.call_manager = CallManager()
+        # from gajim.common.call_manager import CallManager
+        # app.call_manager = CallManager()
 
         from gajim.common.preview import PreviewManager
         app.preview_manager = PreviewManager()
@@ -215,7 +214,7 @@ class CoreApplication(ged.EventHelper):
         ps = ps.sort_stats(SortKey.TIME)
         ps.print_stats()
 
-    def start_shutdown(self, *args: Any, **kwargs: Any) -> None:
+    def start_shutdown(self) -> None:
         app.app.systray.shutdown()
 
         accounts_to_disconnect: dict[str, Client] = {}
@@ -239,7 +238,7 @@ class CoreApplication(ged.EventHelper):
                                        _on_disconnect)
 
         for client in accounts_to_disconnect.values():
-            client.change_status('offline', kwargs.get('message', ''))
+            client.change_status('offline', '')
 
     def _shutdown_core(self) -> None:
         # Commit any outstanding SQL transactions
