@@ -57,7 +57,7 @@ class AvatarSize(IntEnum):
     SHOW_CIRCLE = 24
     SMALL = 24
     ROSTER = 32
-    START_CHAT = 40
+    START_CHAT = 32
     VCARD_HEADER = 40
     ACCOUNT_SIDE_BAR = 40
     WORKSPACE = 40
@@ -1046,7 +1046,7 @@ TRUST_SYMBOL_DATA = {
                       _('Trust Not Decided'),
                       'warning-color'),
     Trust.BLIND: ('security-medium-symbolic',
-                  _('Unverified'),
+                  _('Blind Trust'),
                   'encrypted-color'),
     Trust.VERIFIED: ('security-high-symbolic',
                      _('Verified'),
