@@ -13,11 +13,13 @@ from gi.repository import GLib
 from gajim.common import app
 from gajim.common import events
 from gajim.common import ged
-from gajim.common import helpers
 from gajim.common.modules.contacts import BareContact
 from gajim.common.modules.contacts import GroupchatContact
 from gajim.common.modules.contacts import GroupchatParticipant
 from gajim.common.structs import OutgoingMessage
+from gajim.common.util.status import get_client_status
+from gajim.common.util.status import get_global_show
+from gajim.common.util.status import get_global_status_message
 
 log = logging.getLogger('gajim.c.dbus.remote_control')
 
@@ -169,8 +171,10 @@ class Server:
 
 class GajimRemote(Server):
     def __init__(self) -> None:
+        application_id = app.app.get_application_id()
+        assert application_id is not None
         self._con = Gio.bus_get_sync(Gio.BusType.SESSION, None)
-        Gio.bus_own_name_on_connection(self._con, 'org.gajim.Gajim',
+        Gio.bus_own_name_on_connection(self._con, application_id,
                                        Gio.BusNameOwnerFlags.NONE, None, None)
         super().__init__(self._con, '/org/gajim/dbus/RemoteObject')
 
@@ -225,13 +229,13 @@ class GajimRemote(Server):
     @staticmethod
     def get_status(account: str) -> str:
         if not account:
-            return helpers.get_global_show()
-        return helpers.get_client_status(account)
+            return get_global_show()
+        return get_client_status(account)
 
     @staticmethod
     def get_status_message(account: str) -> str:
         if not account:
-            return str(helpers.get_global_status_message())
+            return get_global_status_message()
         return app.get_client(account).status_message
 
     @staticmethod
