@@ -9,6 +9,7 @@ from typing import Any
 from typing import Union
 
 import datetime
+import json
 from collections.abc import Callable
 from dataclasses import dataclass
 from dataclasses import field
@@ -16,6 +17,7 @@ from functools import cached_property
 
 from nbxmpp.const import Affiliation
 from nbxmpp.const import InviteType
+from nbxmpp.const import MessageType as NBXMPPMessageType
 from nbxmpp.const import Role
 from nbxmpp.const import StatusCode
 from nbxmpp.modules.security_labels import Catalog
@@ -29,12 +31,15 @@ from gajim.common import app
 from gajim.common.const import EncryptionInfoMsg
 from gajim.common.const import JingleState
 from gajim.common.file_props import FileProp
+from gajim.common.helpers import get_uuid
 from gajim.common.storage.archive import models as mod
 from gajim.common.storage.archive.const import MessageType
+from gajim.common.storage.base import Encoder
 
 if typing.TYPE_CHECKING:
     from gajim.common.client import Client
     from gajim.common.modules.httpupload import HTTPFileTransfer
+    from gajim.plugins.manifest import PluginManifest
 
 ChatListEventT = Union[
     'MessageReceived',
@@ -51,6 +56,15 @@ ChatListEventT = Union[
 @dataclass
 class ApplicationEvent:
     name: str
+    context_id: str = field(init=False, default_factory=get_uuid)
+
+    def serialize(self) -> str:
+        '''Convert to a json formatted string for database storage'''
+        event_data = self.__dict__.copy()
+
+        # Drop timestamp, since it is already handled while storing
+        event_data.pop("timestamp", None)
+        return json.dumps(event_data, cls=Encoder)
 
 
 @dataclass
@@ -100,6 +114,7 @@ class PasswordRequired(ApplicationEvent):
 @dataclass
 class Notification(ApplicationEvent):
     name: str = field(init=False, default='notification')
+    context_id: str
     account: str
     type: str
     title: str
@@ -107,10 +122,15 @@ class Notification(ApplicationEvent):
     jid: JID | str | None = None
     sub_type: str | None = None
     sound: str | None = None
-    icon_name: str | None = None
     resource: str | None = None
 
 
+@dataclass
+class NotificationWithdrawn(ApplicationEvent):
+    name: str = field(init=False, default='notification-withdrawn')
+    context_id: str
+
+
 @dataclass
 class ChatRead(ApplicationEvent):
     name: str = field(init=False, default='chat-read')
@@ -304,7 +324,7 @@ class DisplayedReceived(ApplicationEvent):
     account: str
     jid: JID
     properties: Any
-    type: str
+    type: NBXMPPMessageType
     is_muc_pm: bool
     marker_id: str
 
@@ -632,7 +652,7 @@ class PresenceReceived(ApplicationEvent):
 
 @dataclass
 class SubscribePresenceReceived(ApplicationEvent):
-    name: str = field(init=False, default='subscribe-presence-received')
+    name: str = field(init=False, default='subscription-request')
     conn: 'Client'
     account: str
     jid: str
@@ -674,6 +694,12 @@ class AllowGajimUpdateCheck(ApplicationEvent):
     name: str = field(init=False, default='allow-gajim-update-check')
 
 
+@dataclass
+class PluginUpdatesAvailable(ApplicationEvent):
+    name: str = field(init=False, default='plugin-updates-available')
+    manifests: list[PluginManifest]
+
+
 @dataclass
 class GajimUpdateAvailable(ApplicationEvent):
     name: str = field(init=False, default='gajim-update-available')
@@ -727,6 +753,14 @@ class MUCRoomDestroyed(ApplicationEvent):
     alternate: JID | None
 
 
+@dataclass
+class MUCRoomVoiceRequestError(ApplicationEvent):
+    name: str = field(init=False, default='muc-room-voice-request-error')
+    timestamp: datetime.datetime
+    message_id: str
+    error: Any
+
+
 @dataclass
 class MUCUserHatsChanged(ApplicationEvent):
     name: str = field(init=False, default='muc-user-hats-changed')
@@ -827,7 +861,15 @@ class DBMigrationProgress(ApplicationEvent):
 class DBMigrationFinished(ApplicationEvent):
     name: str = field(init=False, default='db-migration-finished')
 
+
 @dataclass
 class DBMigrationError(ApplicationEvent):
     name: str = field(init=False, default='db-migration-error')
     exception: Exception
+
+
+@dataclass
+class ContactBlocked(ApplicationEvent):
+    name: str = field(init=False, default='contact-blocked')
+    account: str
+    jid: JID
