@@ -1,16 +1,6 @@
 # This file is part of Gajim.
 #
-# Gajim is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published
-# by the Free Software Foundation; version 3 only.
-#
-# Gajim is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with Gajim. If not, see <http://www.gnu.org/licenses/>.
+# SPDX-License-Identifier: GPL-3.0-only
 
 
 # Handles Jingle Transports (currently only ICE-UDP)
@@ -66,8 +56,15 @@ class JingleTransport:
     An abstraction of a transport in Jingle sessions
     '''
 
-    __slots__ = ['type_', 'candidates', 'remote_candidates', 'connection',
-                 'file_props', 'ourjid', 'sid']
+    __slots__ = [
+        'candidates',
+        'connection',
+        'file_props',
+        'ourjid',
+        'remote_candidates',
+        'sid',
+        'type_',
+    ]
 
     def __init__(self, type_: TransportType) -> None:
         self.type_ = type_
