@@ -28,8 +28,8 @@ from nbxmpp.structs import MucSubject
 from nbxmpp.structs import TuneData
 
 from gajim.common import app
+from gajim.common import modules
 from gajim.common import types
-from gajim.common.client_modules import ClientModules
 from gajim.common.const import PresenceShowExt
 from gajim.common.const import SimpleClientState
 from gajim.common.helpers import Observable
@@ -253,7 +253,7 @@ class Contacts(BaseModule):
             contact.force_chatstate_update()
 
 
-class CommonContact(Observable, ClientModules):
+class CommonContact(Observable):
     def __init__(self,
                  logger: LogAdapter,
                  jid: JID,
@@ -261,7 +261,6 @@ class CommonContact(Observable, ClientModules):
                  ) -> None:
 
         Observable.__init__(self, logger)
-        ClientModules.__init__(self, account)
         self._jid = jid
         self._account = account
         self._gateway_type: str | None = None
@@ -284,6 +283,9 @@ class CommonContact(Observable, ClientModules):
     def account(self) -> str:
         return self._account
 
+    def get_module(self, name: modules.ModulesLiteralT) -> modules.ModulesT:
+        return modules.get_module(self._account, name)
+
     def _on_signal(
         self,
         _contact: (BareContact |
@@ -924,7 +926,7 @@ class GroupchatContact(CommonContact):
 
     def get_user_nicknames(self) -> list[str]:
         client = app.get_client(self._account)
-        return client.get_module('MUC').get_joined_users(str(self._jid))
+        return client.get_module('MUC').get_joined_users(self._jid)
 
     def get_disco(self, max_age: int = 0) -> DiscoInfo | None:
         return app.storage.cache.get_last_disco_info(self.jid, max_age=max_age)
@@ -1086,16 +1088,7 @@ class GroupchatParticipant(CommonContact):
         return self._presence.hats
 
 
-def can_add_to_roster(
-    contact: BareContact | GroupchatContact | GroupchatParticipant
-) -> bool:
-
-    if isinstance(contact, GroupchatContact):
-        return False
-
-    if isinstance(contact, GroupchatParticipant):
-        return contact.real_jid is not None
-
+def can_add_to_roster(contact: BareContact) -> bool:
     if contact.is_self:
         return False
     return not contact.is_in_roster
