@@ -11,7 +11,7 @@ import logging
 import uuid
 from datetime import datetime
 from datetime import timedelta
-from datetime import timezone
+from datetime import UTC
 
 import sqlalchemy as sa
 from nbxmpp.protocol import JID
@@ -236,7 +236,7 @@ class Migration:
                 sa.select(mod.Moderation.fk_occupant_pk),
                 sa.select(mod.DisplayedMarker.fk_occupant_pk),
             )
-            occupant_pks = set(conn.scalars(stmt))
+            occupant_pks: set[int | None] = set(conn.scalars(stmt))
             occupant_pks.discard(None)
 
             conn.execute(sa.delete(mod.Occupant).where(mod.Occupant.pk.not_in(occupant_pks)))
@@ -255,7 +255,7 @@ class Migration:
                 sa.select(mod.Message.fk_remote_pk),
             )
 
-            occupant_pks = set(conn.scalars(stmt))
+            occupant_pks: set[int | None] = set(conn.scalars(stmt))
             occupant_pks.discard(None)
 
             conn.execute(sa.delete(mod.Remote).where(mod.Remote.pk.not_in(occupant_pks)))
@@ -314,12 +314,12 @@ class Migration:
             to_stanza_ts = None
 
         if to_stanza_ts is not None:
-            to_stanza_ts = datetime.fromtimestamp(float(to_stanza_ts), tz=timezone.utc)
+            to_stanza_ts = datetime.fromtimestamp(float(to_stanza_ts), tz=UTC)
 
         from_stanza_ts = None
         if archive_row.oldest_mam_timestamp is not None:
             from_stanza_ts = datetime.fromtimestamp(
-                float(archive_row.oldest_mam_timestamp), tz=timezone.utc
+                float(archive_row.oldest_mam_timestamp), tz=UTC
             )
 
         if (from_stanza_ts, to_stanza_id, to_stanza_ts) == (None, None, None):
@@ -363,8 +363,23 @@ class Migration:
             )
             return
 
-        account_jid = JID.from_string(log_row.account.jid)
-        remote_jid = JID.from_string(log_row.remote.jid)
+        try:
+            account_jid = JID.from_string(log_row.account.jid)
+        except Exception:
+            log.warning(
+                'Unable to migrate message because of invalid account jid: %s',
+                log_row.account.jid,
+            )
+            return
+
+        try:
+            remote_jid = JID.from_string(log_row.remote.jid)
+        except Exception:
+            log.warning(
+                'Unable to migrate message because of invalid remote jid: %s',
+                log_row.remote.jid,
+            )
+            return
 
         account_pk = self._get_account_pk(conn, account_jid)
         remote_pk = self._get_remote_pk(conn, remote_jid)
@@ -379,9 +394,9 @@ class Migration:
         user_timestamp = additional_data.get('user_timestamp')
         user_delay_ts = None
         if user_timestamp is not None:
-            user_delay_ts = datetime.fromtimestamp(user_timestamp, timezone.utc)
+            user_delay_ts = datetime.fromtimestamp(user_timestamp, UTC)
 
-        timestamp = datetime.fromtimestamp(log_row.time, timezone.utc)
+        timestamp = datetime.fromtimestamp(log_row.time, UTC)
 
         encryption_pk = self._insert_encryption_data(conn, additional_data)
 
@@ -500,15 +515,15 @@ class Migration:
         assert log_row.message_id is not None
 
         by = error.by
-        e_type = error.type  # pyright: ignore
-        text = error.get_text() or None  # pyright: ignore
-        condition = error.condition  # pyright: ignore
-        condition_text = error.condition_data or None  # pyright: ignore
+        e_type = error.type
+        text = error.get_text() or None
+        condition = error.condition
+        condition_text = error.condition_data or None
 
         if e_type is None or condition is None:
             return None
 
-        error_data = {  # pyright: ignore
+        error_data = {
             'fk_account_pk': fk_account_pk,
             'fk_remote_pk': fk_remote_pk,
             'message_id': log_row.message_id,
@@ -521,7 +536,7 @@ class Migration:
         }
 
         try:
-            conn.execute(sa.insert(mod.MessageError), [error_data])  # pyright: ignore
+            conn.execute(sa.insert(mod.MessageError), [error_data])
         except IntegrityError as error:
             if is_unique_constraint_error(error):
                 return
