@@ -16,9 +16,9 @@ from gi.repository import GLib
 
 from gajim.common import regex
 from gajim.common.const import URIType
-from gajim.common.helpers import parse_uri as analyze_uri
-from gajim.common.helpers import validate_jid
+from gajim.common.util.jid import validate_jid
 from gajim.common.util.text import escape_iri_query
+from gajim.common.util.uri import parse_uri as analyze_uri
 
 PRE = '`'
 STRONG = '*'
@@ -33,9 +33,9 @@ PRE_RX = r'(?P<pre>^```.+?(^```$(.|\Z)))'
 PRE_NESTED_RX = r'(?P<pre>^```.+?((^```$(.|\Z))|\Z))'
 QUOTE_RX = r'(?P<quote>^(?=>).*?(^|\Z)(?!>))'
 
-BLOCK_RX = re.compile(PRE_RX + '|' + QUOTE_RX, re.S | re.M)
-BLOCK_NESTED_RX = re.compile(PRE_NESTED_RX + '|' + QUOTE_RX, re.S | re.M)
-UNQUOTE_RX = re.compile(r'^> |^>', re.M)
+BLOCK_RX = re.compile(PRE_RX + '|' + QUOTE_RX, re.DOTALL | re.MULTILINE)
+BLOCK_NESTED_RX = re.compile(PRE_NESTED_RX + '|' + QUOTE_RX, re.DOTALL | re.MULTILINE)
+UNQUOTE_RX = re.compile(r'^> |^>', re.MULTILINE)
 
 URI_OR_JID_RX = re.compile(
     fr'(?P<uri>(?<![\w+.-]){regex.IRI})|(?P<jid>{regex.XMPP.jid})')
@@ -404,7 +404,7 @@ def _make_hyperlink(line: str,
             validate_jid(text)
         except ValueError:
             return None
-        uri = 'about:ambiguous-address?' + escape_iri_query(text)
+        uri = escape_iri_query(text)
 
     else:
         uri = text
