@@ -37,6 +37,7 @@ from gajim.common.util.preview import guess_simple_file_type
 from gajim.common.util.preview import split_geo_uri
 from gajim.common.util.text import remove_invalid_xml_chars
 
+from gajim.gtk.activity_page import ActivityPage
 from gajim.gtk.chat_banner import ChatBanner
 from gajim.gtk.chat_function_page import ChatFunctionPage
 from gajim.gtk.chat_function_page import FunctionMode
@@ -62,6 +63,9 @@ class ChatStack(Gtk.Stack, EventHelper, SignalManager):
 
         self.add_named(ChatPlaceholderBox(), "empty")
 
+        self._activity_page = ActivityPage()
+        self.add_named(self._activity_page, "activity")
+
         self._chat_function_page = ChatFunctionPage()
         self._chat_function_page.connect("finish", self._on_function_finished)
         self._chat_function_page.connect("message", self._on_function_message)
@@ -245,14 +249,26 @@ class ChatStack(Gtk.Stack, EventHelper, SignalManager):
         clipboard: Gdk.Clipboard,
         result: Gio.AsyncResult,
     ) -> None:
-        text = clipboard.read_text_finish(result)
+        text = None
+
+        try:
+            text = clipboard.read_text_finish(result)
+        except Exception as e:
+            log.exception("Error while trying to paste text: %s", e)
+
         if text is None:
+            log.info("No text pasted")
             return
 
         # Reset primary clipboard to what it was before switching chats,
         # otherwise it gets overridden.
         clipboard.set(text)
 
+    def show_activity_page(self, context_id: str | None = None) -> None:
+        if not context_id:
+            self._activity_page.show_default_page()
+        self.set_visible_child_name("activity")
+
     def _on_room_password_required(
         self, _contact: GroupchatContact, _signal_name: str
     ) -> None:
@@ -363,13 +379,19 @@ class ChatStack(Gtk.Stack, EventHelper, SignalManager):
                 return
 
             client = app.get_client(event.account)
+            stanza_id = event.message.stanza_id
             contact = client.get_module("Contacts").get_contact(event.jid)
             assert isinstance(
                 contact, BareContact | GroupchatContact | GroupchatParticipant
             )
-            client.get_module("ChatMarkers").send_displayed_marker(
-                contact, event.message.id, event.message.stanza_id
+            mds_assist_sent = client.get_module("ChatMarkers").send_displayed_marker(
+                contact, event.message.id, stanza_id
             )
+
+            if not mds_assist_sent and stanza_id is not None:
+                by = contact.jid if isinstance(contact, GroupchatContact) else None
+                client.get_module("MDS").set_mds(contact.jid, stanza_id, by)
+
             return
 
         message = event.message
@@ -460,6 +482,7 @@ class ChatStack(Gtk.Stack, EventHelper, SignalManager):
 
         app.ged.raise_event(
             events.Notification(
+                context_id="",
                 account=contact.account,
                 jid=contact.jid,
                 type="incoming-message",
@@ -476,10 +499,10 @@ class ChatStack(Gtk.Stack, EventHelper, SignalManager):
             "send-file",
             "send-file-httpupload",
             # 'send-file-jingle',
-            "show-contact-info",
             "start-video-call",
             "start-voice-call",
             "send-message",
+            "show-contact-info",
             "muc-change-nickname",
             "muc-invite",
             "muc-contact-info",
