@@ -12,7 +12,6 @@ import datetime as dt
 import logging
 from collections import defaultdict
 
-from gi.repository import GObject
 from gi.repository import Gtk
 
 from gajim.common import app
@@ -23,6 +22,10 @@ from gajim.common.modules.contacts import GroupchatContact
 from gajim.common.storage.archive import models as mod
 from gajim.common.storage.archive.const import ChatDirection
 
+from gajim.gtk.emoji_chooser import EmojiChooser
+from gajim.gtk.util.classes import SignalManager
+from gajim.gtk.util.misc import iterate_children
+
 if TYPE_CHECKING:
     from gajim.gtk.conversation.rows.message import MessageRow
 
@@ -30,7 +33,7 @@ MAX_VISIBLE_REACTIONS = 5
 MAX_TOTAL_REACTIONS = 25
 MAX_USERS = 25
 
-log = logging.getLogger('gajim.gtk.conversation.reactions_bar')
+log = logging.getLogger("gajim.gtk.conversation.reactions_bar")
 
 
 class ReactionData(NamedTuple):
@@ -39,25 +42,43 @@ class ReactionData(NamedTuple):
     from_us: bool
 
 
-class ReactionsBar(Gtk.Box):
+class ReactionsBar(Gtk.Box, SignalManager):
     def __init__(self, message_row: MessageRow, contact: types.ChatContactT) -> None:
-        Gtk.Box.__init__(self, spacing=3, no_show_all=True, halign=Gtk.Align.START)
+        Gtk.Box.__init__(self, spacing=3, visible=False, halign=Gtk.Align.START)
+        SignalManager.__init__(self)
+
         self._message_row = message_row
         self._contact = contact
         if isinstance(self._contact, GroupchatContact):
-            self._contact.connect('state-changed', self._on_muc_state_changed)
+            self._contact.connect("state-changed", self._on_muc_state_changed)
 
         self._client = app.get_client(self._contact.account)
-        self._client.connect_signal('state-changed', self._on_client_state_changed)
+        self._client.connect_signal("state-changed", self._on_client_state_changed)
         self.set_sensitive(self._get_reactions_enabled())
 
         self._reactions: list[mod.Reaction] = []
 
-        add_reaction_button = AddReactionButton()
-        add_reaction_button.get_style_context().add_class('reaction')
-        add_reaction_button.get_style_context().add_class('flat')
-        add_reaction_button.connect('emoji-added', self._on_emoji_added)
-        self.pack_end(add_reaction_button, False, False, 0)
+        self._add_reaction_button = Gtk.MenuButton(
+            icon_name="lucide-smile-plus-symbolic",
+            tooltip_text=_("Add Reaction…"),
+        )
+
+        self._add_reaction_button.set_create_popup_func(self._on_emoji_create_popover)
+        self._add_reaction_button.add_css_class("flat")
+        self._add_reaction_button.add_css_class("reaction-add-show-all")
+
+        self.append(self._add_reaction_button)
+
+    def do_unroot(self) -> None:
+        self._reactions.clear()
+        self._contact.disconnect_all_from_obj(self)
+        self._client.disconnect_all_from_obj(self)
+        self._add_reaction_button.set_create_popup_func(None)
+        del self._add_reaction_button
+        del self._message_row
+        self._disconnect_all()
+        Gtk.Box.do_unroot(self)
+        app.check_finalize(self)
 
     def _on_client_state_changed(self, *args: Any) -> None:
         self.set_sensitive(self._get_reactions_enabled())
@@ -89,17 +110,17 @@ class ReactionsBar(Gtk.Box):
                 continue
 
             if reaction.direction == ChatDirection.OUTGOING:
-                username = _('Me')
+                username = _("Me")
             else:
                 if isinstance(self._contact, BareContact):
                     username = self._contact.name
                 else:
                     if reaction.occupant is None or reaction.occupant.nickname is None:
-                        log.debug('Ignoring MUC reaction without occupant')
+                        log.debug("Ignoring MUC reaction without occupant")
                         continue
                     username = reaction.occupant.nickname
 
-            for emoji in reaction.emojis.split(';'):
+            for emoji in reaction.emojis.split(";"):
                 aggregated_reactions[emoji].append(
                     ReactionData(
                         username=username,
@@ -108,15 +129,16 @@ class ReactionsBar(Gtk.Box):
                     )
                 )
 
-        return aggregated_reactions
+        # Multisort dict, first for emojis, afterwards for count
+        emoji_sorted = sorted(aggregated_reactions.items())
+        count_sorted = sorted(emoji_sorted, reverse=True, key=lambda tup: len(tup[1]))
+        return dict(count_sorted)
 
     def get_our_reactions(self) -> set[str]:
         our_reactions: set[str] = set()
         for reaction in self._reactions:
             if reaction.direction == ChatDirection.OUTGOING:
-                our_reactions = {
-                    emoji for emoji in reaction.emojis.split(';') if emoji
-                }
+                our_reactions = {emoji for emoji in reaction.emojis.split(";") if emoji}
                 break
 
         return our_reactions
@@ -124,44 +146,51 @@ class ReactionsBar(Gtk.Box):
     def _on_reaction_clicked(self, reaction_button: ReactionButton) -> None:
         self._message_row.send_reaction(reaction_button.emoji)
 
-    def _on_emoji_added(self, _widget: AddReactionButton, emoji: str) -> None:
+    def _on_emoji_added(self, _widget: EmojiChooser, emoji: str) -> None:
+        # Remove emoji variant selectors
+        emoji = emoji.strip("\uFE0E\uFE0F")
         self._message_row.send_reaction(emoji, toggle=False)
 
     def update_from_reactions(self, reactions: list[mod.Reaction]) -> None:
-        for widget in self.get_children():
-            if isinstance(widget, AddReactionButton):
-                continue
-
+        for widget in list(iterate_children(self)):
             if isinstance(widget, MoreReactionsButton):
                 widget.hide_popover()
+                self.remove(widget)
+                continue
 
-            widget.destroy()
+            if isinstance(widget, Gtk.MenuButton):
+                continue
+
+            self.remove(widget)
 
         self._reactions = reactions
 
         aggregated_reactions = self._aggregate_reactions(reactions)
         if not aggregated_reactions:
-            self.set_no_show_all(True)
-            self.hide()
+            self.set_visible(False)
             return
 
         more_reactions_button = None
         for index, (emoji, data) in enumerate(aggregated_reactions.items()):
             reaction_button = ReactionButton(emoji, data)
-            reaction_button.connect('clicked', self._on_reaction_clicked)
+            self._connect(reaction_button, "clicked", self._on_reaction_clicked)
             if index + 1 <= MAX_VISIBLE_REACTIONS:
-                self.pack_start(reaction_button, False, False, 0)
+                self.prepend(reaction_button)
             elif index + 1 > MAX_VISIBLE_REACTIONS and index + 1 <= MAX_TOTAL_REACTIONS:
                 if more_reactions_button is None:
                     more_reactions_button = MoreReactionsButton()
-                    self.pack_start(more_reactions_button, False, False, 0)
+                    self.append(more_reactions_button)
                 more_reactions_button.add_reaction(reaction_button)
             else:
-                log.debug('Too many reactions: %s', len(aggregated_reactions))
+                log.debug("Too many reactions: %s", len(aggregated_reactions))
                 break
 
-        self.set_no_show_all(False)
-        self.show_all()
+        self.set_visible(True)
+
+    def _on_emoji_create_popover(self, button: Gtk.MenuButton) -> None:
+        emoji_chooser = app.window.get_emoji_chooser()
+        button.set_popover(emoji_chooser)
+        emoji_chooser.set_emoji_picked_func(self._on_emoji_added)
 
 
 class ReactionButton(Gtk.Button):
@@ -171,9 +200,9 @@ class ReactionButton(Gtk.Button):
 
         # Add emoji presentation selector, otherwise depending on the font
         # emojis might be displayed in its text variant
-        emoji_presentation_form = f'{emoji}\uFE0F'
+        emoji_presentation_form = f"{emoji}\uFE0F"
 
-        format_string = app.settings.get('date_time_format')
+        format_string = app.settings.get("date_time_format")
         tooltip_markup = f'<span size="200%">{emoji_presentation_form}</span>\n'
 
         self.from_us = False
@@ -182,34 +211,32 @@ class ReactionButton(Gtk.Button):
                 self.from_us = True
 
             dt_str = reaction.timestamp.astimezone().strftime(format_string)
-            tooltip_markup += (f'{reaction.username} ({dt_str})\n')
+            tooltip_markup += f"{reaction.username} ({dt_str})\n"
         if len(reaction_data) > MAX_USERS:
-            tooltip_markup += _('And more...')
+            tooltip_markup += _("And more...")
 
         self.set_tooltip_markup(tooltip_markup.strip())
 
-        self.get_style_context().add_class('flat')
-        self.get_style_context().add_class('reaction')
+        self.add_css_class("flat")
+        self.add_css_class("reaction")
         if self.from_us:
-            self.get_style_context().add_class('reaction-from-us')
+            self.add_css_class("reaction-from-us")
 
         emoji_label = Gtk.Label(label=emoji_presentation_form)
         count_label = Gtk.Label(label=str(len(reaction_data)))
-        count_label.get_style_context().add_class('monospace')
+        count_label.add_css_class("monospace")
 
         self._box = Gtk.Box(spacing=3)
-        self._box.add(emoji_label)
-        self._box.add(count_label)
-        self.add(self._box)
-
-        self.show_all()
+        self._box.append(emoji_label)
+        self._box.append(count_label)
+        self.set_child(self._box)
 
 
 class MoreReactionsButton(Gtk.MenuButton):
     def __init__(self) -> None:
-        Gtk.MenuButton.__init__(self, tooltip_text=_('Show all reactions'))
-        self.get_style_context().add_class('flat')
-        self.get_style_context().add_class('reaction')
+        Gtk.MenuButton.__init__(self, tooltip_text=_("Show all reactions"))
+        self.add_css_class("flat")
+        self.add_css_class("reaction-add-show-all")
 
         self._flow_box = Gtk.FlowBox(
             row_spacing=3,
@@ -218,67 +245,16 @@ class MoreReactionsButton(Gtk.MenuButton):
             min_children_per_line=3,
             max_children_per_line=3,
         )
-        self._flow_box.get_style_context().add_class('padding-6')
+        self._flow_box.add_css_class("p-6")
 
         popover = Gtk.Popover()
-        popover.add(self._flow_box)
+        popover.set_child(self._flow_box)
         self.set_popover(popover)
 
-        self.show_all()
-
     def hide_popover(self) -> None:
         popover = self.get_popover()
         if popover is not None:
             popover.popdown()
 
     def add_reaction(self, reaction_button: ReactionButton) -> None:
-        self._flow_box.add(reaction_button)
-        self._flow_box.show_all()
-
-
-class AddReactionButton(Gtk.Button):
-
-    __gsignals__ = {
-        'emoji-added': (GObject.SignalFlags.RUN_LAST, None, (str,)),
-    }
-
-    def __init__(self) -> None:
-        Gtk.Button.__init__(self, tooltip_text=_('Add reaction'))
-        icon = Gtk.Image.new_from_icon_name(
-            'lucide-smile-plus-symbolic', Gtk.IconSize.BUTTON
-        )
-        self._dummy_entry = Gtk.Entry(
-            width_chars=0,
-            editable=True,
-            no_show_all=True,
-        )
-        self._dummy_entry.get_style_context().add_class('flat')
-        self._dummy_entry.get_style_context().add_class('dummy-emoji-entry')
-        self._dummy_entry.connect('insert-text', self._on_insert_text)
-
-        box = Gtk.Box()
-        box.add(icon)
-        box.add(self._dummy_entry)
-        self.add(box)
-        self.set_tooltip_text(_('Add Reaction…'))
-
-        # Use connect_after to allow other widgets to connect beforehand
-        self.connect_after('clicked', self._on_clicked)
-
-        self.show_all()
-
-    def _on_clicked(self, _button: Gtk.Button) -> None:
-        self._dummy_entry.show()
-        self._dummy_entry.emit('insert-emoji')
-
-    def _on_insert_text(
-        self, entry: Gtk.Entry, text: str, _length: int, _position: int
-    ) -> int:
-        entry.stop_emission_by_name('insert-text')
-        entry.hide()
-
-        # Remove emoji variant selectors
-        text = text.strip('\uFE0E\uFE0F')
-        if text:
-            self.emit('emoji-added', text)
-        return 0
+        self._flow_box.append(reaction_button)
