@@ -19,6 +19,7 @@ from gi.repository import Gio
 from gi.repository import GLib
 from gi.repository import Gtk
 from nbxmpp import JID
+from nbxmpp.types import BlockingReportValues
 
 from gajim.common import app
 from gajim.common import events
@@ -34,15 +35,14 @@ from gajim.common.i18n import _
 from gajim.common.modules.contacts import BareContact
 from gajim.common.modules.contacts import GroupchatContact
 from gajim.common.modules.contacts import GroupchatParticipant
+from gajim.common.modules.contacts import ResourceContact
 from gajim.common.storage.archive.const import MessageType
 from gajim.common.util.uri import open_file
 from gajim.common.util.uri import open_uri
 from gajim.common.util.uri import show_in_folder
-from gajim.plugins.manifest import PluginManifest
-from gajim.plugins.repository import PluginRepository
 
 from gajim.gtk.account_side_bar import AccountSideBar
-from gajim.gtk.app_side_bar import AppSideBar
+from gajim.gtk.activity_side_bar import ActivitySideBar
 from gajim.gtk.builder import get_builder
 from gajim.gtk.chat_list import ChatList
 from gajim.gtk.chat_list_row import ChatListRow
@@ -55,6 +55,7 @@ from gajim.gtk.dialogs import SimpleDialog
 from gajim.gtk.emoji_chooser import EmojiChooser
 from gajim.gtk.main_menu_button import MainMenuButton
 from gajim.gtk.main_stack import MainStack
+from gajim.gtk.structs import AccountJidParam
 from gajim.gtk.structs import actionmethod
 from gajim.gtk.structs import AddChatActionParams
 from gajim.gtk.structs import ChatListEntryParam
@@ -104,9 +105,8 @@ class MainWindow(Gtk.ApplicationWindow, EventHelper):
 
         self._ui.left_grid.attach(MainMenuButton(), 0, 0, 1, 1)
 
-        self._app_page = self._main_stack.get_app_page()
-        self._app_side_bar = AppSideBar(self._app_page)
-        self._ui.app_box.prepend(self._app_side_bar)
+        self._activity_side_bar = ActivitySideBar(self._chat_page)
+        self._ui.activity_box.prepend(self._activity_side_bar)
 
         self._workspace_side_bar = WorkspaceSideBar(self._chat_page)
         self._ui.workspace_scrolled.set_child(self._workspace_side_bar)
@@ -138,8 +138,6 @@ class MainWindow(Gtk.ApplicationWindow, EventHelper):
                 ("file-request-received", ged.GUI1, self._on_file_request),
                 ("account-enabled", ged.GUI1, self._on_account_enabled),
                 ("account-disabled", ged.GUI1, self._on_account_disabled),
-                ("allow-gajim-update-check", ged.GUI1, self._on_allow_gajim_update),
-                ("gajim-update-available", ged.GUI1, self._on_gajim_update_available),
                 ("roster-item-exchange", ged.GUI1, self._on_roster_item_exchange),
                 ("plain-connection", ged.GUI1, self._on_plain_connection),
                 ("password-required", ged.GUI1, self._on_password_required),
@@ -150,13 +148,6 @@ class MainWindow(Gtk.ApplicationWindow, EventHelper):
             ]
         )
 
-        app.plugin_repository.connect(
-            "plugin-updates-available", self._on_plugin_updates_available
-        )
-        app.plugin_repository.connect(
-            "auto-update-finished", self._on_plugin_auto_update_finished
-        )
-
         self._check_for_account()
         self._load_chats()
         self._load_unread_counts()
@@ -185,6 +176,11 @@ class MainWindow(Gtk.ApplicationWindow, EventHelper):
     def get_emoji_chooser(self) -> EmojiChooser:
         if self._emoji_chooser is None:
             self._emoji_chooser = EmojiChooser()
+
+        parent = cast(Gtk.MenuButton | None, self._emoji_chooser.get_parent())
+        if parent is not None:
+            parent.set_popover(None)
+
         return self._emoji_chooser
 
     def show(self) -> None:
@@ -241,8 +237,6 @@ class MainWindow(Gtk.ApplicationWindow, EventHelper):
             self.hide_window()
 
     def _on_account_enabled(self, event: events.AccountEnabled) -> None:
-        self._account_side_bar.add_account(event.account)
-        self._main_stack.add_account_page(event.account)
         client = app.get_client(event.account)
         client.connect_signal("state-changed", self._on_client_state_changed)
         client.connect_signal("resume-successful", self._on_client_resume_successful)
@@ -250,13 +244,9 @@ class MainWindow(Gtk.ApplicationWindow, EventHelper):
     def _on_account_disabled(self, event: events.AccountDisabled) -> None:
         workspace_id = self._workspace_side_bar.get_first_workspace()
         self.activate_workspace(workspace_id)
-        self._account_side_bar.remove_account(event.account)
         self._main_stack.remove_account_page(event.account)
         self._main_stack.remove_chats_for_account(event.account)
 
-    def update_account_unread_count(self, account: str, count: int) -> None:
-        self._account_side_bar.update_unread_count(account, count)
-
     def _on_key_pressed(
         self,
         _event_controller_key: Gtk.EventControllerKey,
@@ -282,15 +272,6 @@ class MainWindow(Gtk.ApplicationWindow, EventHelper):
 
         app.app.update_feature_actions_state(client.account)
 
-    def _on_allow_gajim_update(self, event: events.AllowGajimUpdateCheck) -> None:
-        self.add_app_message(event.name)
-
-    def _on_gajim_update_available(self, event: events.GajimUpdateAvailable) -> None:
-
-        self.add_app_message(
-            event.name, new_version=event.version, new_setup_url=event.setup_url
-        )
-
     @staticmethod
     def _on_roster_item_exchange(event: events.RosterItemExchangeEvent) -> None:
         open_window(
@@ -446,6 +427,7 @@ class MainWindow(Gtk.ApplicationWindow, EventHelper):
             ("mark-workspace-as-read", self._mark_workspace_as_read),
             ("add-chat", self._add_chat),
             ("add-group-chat", self._add_group_chat),
+            ("chat-contact-info", self._on_chat_contact_info),
         ]
 
         for action, func in actions:
@@ -692,6 +674,17 @@ class MainWindow(Gtk.ApplicationWindow, EventHelper):
 
         self.get_clipboard().set(param.get_string())
 
+    @actionmethod
+    def _on_chat_contact_info(
+        self, _action: Gio.SimpleAction, params: AccountJidParam
+    ) -> None:
+        client = app.get_client(params.account)
+        contact = client.get_module("Contacts").get_contact(params.jid)
+        if isinstance(contact, GroupchatContact):
+            open_window("GroupchatDetails", contact=contact)
+        else:
+            open_window("ContactInfo", account=contact.account, contact=contact)
+
     @actionmethod
     def _on_moderate_message(
         self, _action: Gio.SimpleAction, params: ModerateMessageParam
@@ -835,9 +828,9 @@ class MainWindow(Gtk.ApplicationWindow, EventHelper):
             chat_list_stack.set_chat_unread_count(chat.account, chat.jid, chat.count)
 
     def show_account_page(self, account: str) -> None:
-        self._app_side_bar.unselect_all()
+        self._activity_side_bar.unselect()
         self._workspace_side_bar.unselect_all()
-        self._account_side_bar.activate_account_page(account)
+        self._account_side_bar.select()
         self._main_stack.show_account(account)
 
     def get_active_workspace(self) -> str | None:
@@ -969,8 +962,8 @@ class MainWindow(Gtk.ApplicationWindow, EventHelper):
             self.activate_workspace(workspace_id)
 
     def activate_workspace(self, workspace_id: str) -> None:
-        self._app_side_bar.unselect_all()
-        self._account_side_bar.unselect_all()
+        self._activity_side_bar.unselect()
+        self._account_side_bar.unselect()
         self._main_stack.show_chats(workspace_id)
         self._workspace_side_bar.activate_workspace(workspace_id)
 
@@ -1055,8 +1048,8 @@ class MainWindow(Gtk.ApplicationWindow, EventHelper):
             chat_list.clear_chat_list_row(account, jid)
 
     def select_chat(self, account: str, jid: JID) -> None:
-        self._app_side_bar.unselect_all()
-        self._account_side_bar.unselect_all()
+        self._activity_side_bar.unselect()
+        self._account_side_bar.unselect()
         self._main_stack.show_chat_page()
         self._chat_page.select_chat(account, jid)
 
@@ -1074,19 +1067,11 @@ class MainWindow(Gtk.ApplicationWindow, EventHelper):
         if chat_list is not None:
             chat_list.select_chat_number(number)
 
-    def show_app_page(self) -> None:
-        self._account_side_bar.unselect_all()
+    def show_activity_page(self, context_id: str | None = None) -> None:
+        self._account_side_bar.unselect()
         self._workspace_side_bar.unselect_all()
-        self._main_stack.show_app_page()
-
-    def add_app_message(
-        self,
-        category: str,
-        new_version: str | None = None,
-        new_setup_url: str | None = None,
-    ) -> None:
-
-        self._app_page.add_app_message(category, new_version, new_setup_url)
+        self._activity_side_bar.select()
+        self._main_stack.show_activity_page(context_id)
 
     def get_control(self) -> ChatControl:
         return self._chat_page.get_control()
@@ -1119,7 +1104,13 @@ class MainWindow(Gtk.ApplicationWindow, EventHelper):
         count = chat_list_stack.get_chat_unread_count(account, jid, include_silent)
         return count or 0
 
-    def mark_as_read(self, account: str, jid: JID, send_marker: bool = True) -> None:
+    def mark_as_read(
+        self,
+        account: str,
+        jid: JID,
+        *,
+        is_sync: bool = False,
+    ) -> None:
 
         unread_count = self.get_chat_unread_count(account, jid, include_silent=True)
 
@@ -1133,26 +1124,34 @@ class MainWindow(Gtk.ApplicationWindow, EventHelper):
         chat_list_stack = self._chat_page.get_chat_list_stack()
         chat_list_stack.mark_as_read(account, jid)
 
-        if not send_marker or not unread_count:
+        if not unread_count or is_sync:
             # Read marker must be sent only once
             return
 
+        if not app.account_is_connected(account):
+            return
+
+        client = app.get_client(account)
+        contact = client.get_module("Contacts").get_contact(jid)
+        assert not isinstance(contact, ResourceContact)
+
+        if not client.get_module("MAM").is_catch_up_finished(contact):
+            # Dont set read state before we have all messages
+            return
+
         last_message = app.storage.archive.get_last_conversation_row(account, jid)
         if last_message is None or last_message.id is None:
             return
 
-        client = app.get_client(account)
-        contact = client.get_module("Contacts").get_contact(jid)
-        assert isinstance(
-            contact, BareContact | GroupchatContact | GroupchatParticipant
-        )
-
-        client.get_module("ChatMarkers").send_displayed_marker(
+        mds_assist_sent = client.get_module("ChatMarkers").send_displayed_marker(
             contact, last_message.id, last_message.stanza_id
         )
 
-    def _on_window_active(self, window: Gtk.ApplicationWindow, _param: Any) -> None:
+        if not mds_assist_sent and last_message.stanza_id is not None:
+            by = contact.jid if isinstance(contact, GroupchatContact) else None
+            client.get_module("MDS").set_mds(contact.jid, last_message.stanza_id, by)
 
+    def _on_window_active(self, window: Gtk.ApplicationWindow, _param: Any) -> None:
         if not window.is_active():
             return
 
@@ -1161,7 +1160,7 @@ class MainWindow(Gtk.ApplicationWindow, EventHelper):
         if not control.has_active_chat():
             return
 
-        if control.get_autoscroll():
+        if control.view_is_at_bottom():
             self.mark_as_read(control.contact.account, control.contact.jid)
 
     def get_preferred_ft_method(self, contact: types.ChatContactT) -> str | None:
@@ -1232,7 +1231,7 @@ class MainWindow(Gtk.ApplicationWindow, EventHelper):
             return
 
         # TODO: Keep "confirm_block" setting?
-        def _block_contact(report: str | None = None) -> None:
+        def _block_contact(report: BlockingReportValues | None = None) -> None:
             client.get_module("Blocking").block([contact.jid], report)
             self._chat_page.remove_chat(account, contact.jid)
 
@@ -1318,7 +1317,7 @@ class MainWindow(Gtk.ApplicationWindow, EventHelper):
         if event.marker_id not in (last_message.id, last_message.stanza_id):
             return
 
-        self.mark_as_read(event.account, event.jid, send_marker=False)
+        self.mark_as_read(event.account, event.jid, is_sync=True)
 
     def _on_call_started(self, event: events.CallStarted) -> None:
         # Make sure there is only one window
@@ -1348,49 +1347,4 @@ class MainWindow(Gtk.ApplicationWindow, EventHelper):
             app.settings.set("mainwin_height", window_height)
 
         app.settings.save()
-
-        def on_continue2(message: str | None) -> None:
-            app.app.start_shutdown(message=message)
-
-        def on_continue(message: str | None) -> None:
-            if message is None:
-                # user pressed Cancel to change status message dialog
-                return
-
-            # Check for unread messages
-            if self.get_total_unread_count():
-                ConfirmationDialog(
-                    _("You Have Unread Messages"),
-                    _(
-                        "Messages will only be available for reading them later "
-                        "if storing chat history is enabled and if the contact "
-                        "is in your contact list."
-                    ),
-                    [
-                        DialogButton.make("Cancel"),
-                        DialogButton.make(
-                            "Remove",
-                            text=_("_Quit"),
-                            callback=on_continue2,
-                            args=[message],
-                        ),
-                    ],
-                )
-                return
-
-            on_continue2(message)
-
-        on_continue("")
-
-    def _on_plugin_updates_available(
-        self,
-        _repository: PluginRepository,
-        _signal_name: str,
-        manifests: list[PluginManifest],
-    ) -> None:
-        self._app_page.add_plugin_update_message(manifests)
-
-    def _on_plugin_auto_update_finished(
-        self, _repository: PluginRepository, _signal_name: str
-    ) -> None:
-        self.add_app_message("plugin-updates-finished")
+        app.app.start_shutdown()
