@@ -62,7 +62,7 @@ class MessageInputTextView(GtkSource.View):
             GObject.SignalFlags.RUN_LAST | GObject.SignalFlags.ACTION,
             None,
             (),
-        )
+        ),
     }
 
     def __init__(self, parent: Gtk.Widget) -> None:
@@ -72,6 +72,7 @@ class MessageInputTextView(GtkSource.View):
             wrap_mode=Gtk.WrapMode.WORD_CHAR,
             margin_top=3,
             margin_bottom=3,
+            valign=Gtk.Align.CENTER,
         )
 
         self._parent = parent
@@ -162,6 +163,7 @@ class MessageInputTextView(GtkSource.View):
             self._completion_popover.popdown()
 
         self._on_text_changed()
+
         self.emit("buffer-changed")
 
     @staticmethod
@@ -394,7 +396,13 @@ class MessageInputTextView(GtkSource.View):
     def _on_clipboard_read_text_finished(
         self, clipboard: Gdk.Clipboard, result: Gio.AsyncResult, action_name: str
     ) -> None:
-        text = clipboard.read_text_finish(result)
+        text = None
+
+        try:
+            text = clipboard.read_text_finish(result)
+        except Exception as e:
+            log.exception("Error while trying to paste text: %s", e)
+
         if text is None:
             log.info("No text pasted")
             return
