@@ -15,7 +15,7 @@ from gi.repository import Gtk
 from gi.repository import Pango
 from nbxmpp.errors import MalformedStanzaError
 from nbxmpp.errors import StanzaError
-from nbxmpp.modules.dataforms import SimpleDataForm
+from nbxmpp.modules.dataforms import DataForm
 from nbxmpp.namespaces import Namespace
 from nbxmpp.structs import LastActivityData
 from nbxmpp.structs import SoftwareVersionResult
@@ -25,14 +25,15 @@ from gajim.common import app
 from gajim.common import ged
 from gajim.common.const import TLS_VERSION_STRINGS
 from gajim.common.events import ServerDiscoReceived
+from gajim.common.ged import EventHelper
 from gajim.common.i18n import _
 from gajim.common.util.uri import open_uri
 
 from gajim.gtk.builder import get_builder
 from gajim.gtk.certificate_dialog import CertificateBox
-from gajim.gtk.util import EventHelper
+from gajim.gtk.widgets import GajimAppWindow
 
-log = logging.getLogger('gajim.gtk.server_info')
+log = logging.getLogger("gajim.gtk.server_info")
 
 
 class Feature(NamedTuple):
@@ -41,84 +42,78 @@ class Feature(NamedTuple):
     additional: str | None = None
 
 
-class ServerInfo(Gtk.ApplicationWindow, EventHelper):
+class ServerInfo(GajimAppWindow, EventHelper):
     def __init__(self, account: str) -> None:
-        Gtk.ApplicationWindow.__init__(self)
+        GajimAppWindow.__init__(
+            self,
+            name="ServerInfo",
+            title=_("Server Info"),
+            default_width=600,
+            default_height=700,
+        )
         EventHelper.__init__(self)
-        self.set_name('ServerInfo')
-        self.set_application(app.app)
-        self.set_position(Gtk.WindowPosition.CENTER)
-        self.set_default_size(500, 600)
-        self.set_show_menubar(False)
-        self.set_title(_('Server Info'))
-        self.set_type_hint(Gdk.WindowTypeHint.DIALOG)
 
         self.account = account
         self._client = app.get_client(account)
-        self._destroyed = False
 
-        if app.settings.get('use_kib_mib'):
+        if app.settings.get("use_kib_mib"):
             self._units = GLib.FormatSizeFlags.IEC_UNITS
         else:
             self._units = GLib.FormatSizeFlags.DEFAULT
 
-        self._ui = get_builder('server_info.ui')
-        self.add(self._ui.server_info_notebook)
+        self._ui = get_builder("server_info.ui")
+        self.set_child(self._ui.server_info_notebook)
 
-        self.connect('destroy', self._on_destroy)
-        self.connect('key-press-event', self._on_key_press)
-        self._ui.connect_signals(self)
+        self._connect(
+            self._ui.clipboard_button, "clicked", self._on_clipboard_button_clicked
+        )
 
-        self.register_events([
-            ('server-disco-received', ged.GUI1, self._server_disco_received),
-        ])
+        self.register_events(
+            [
+                ("server-disco-received", ged.GUI1, self._server_disco_received),
+            ]
+        )
 
-        self._version = ''
+        self._version = ""
         self._hostname = app.get_hostname_from_account(account, prefer_custom=True)
         self._ui.server_hostname.set_text(self._hostname)
 
         domain = self._client.get_own_jid().domain
-        self._client.get_module('SoftwareVersion').request_software_version(
-            domain, callback=self._software_version_received)
+        self._client.get_module("SoftwareVersion").request_software_version(
+            domain, callback=self._software_version_received
+        )
 
-        self._client.get_module('LastActivity').request_last_activity(
-            domain, callback=self._on_last_activity)
+        self._client.get_module("LastActivity").request_last_activity(
+            domain, callback=self._on_last_activity
+        )
 
-        server_info = self._client.get_module('Discovery').server_info
+        server_info = self._client.get_module("Discovery").server_info
         self._add_contact_addresses(server_info.dataforms)
 
         self._add_connection_info()
 
         if self._client.certificate is None:
-            self._ui.no_certificate_label.show()
+            self._ui.no_certificate_label.set_visible(True)
         else:
             cert_box = CertificateBox(account, self._client.certificate)
-            self._ui.cert_scrolled.add(cert_box)
-            self._ui.cert_scrolled.show()
-            cert_box.show_all()
+            self._ui.cert_scrolled.set_child(cert_box)
+            self._ui.cert_scrolled.set_visible(True)
 
         for feature in self._get_features():
             self._add_feature(feature)
-        self._clipboard = Gtk.Clipboard.get(Gdk.SELECTION_CLIPBOARD)
 
-        self.show_all()
-
-    def _on_destroy(self, *args: Any) -> None:
-        self._destroyed = True
-
-    def _on_key_press(self, _widget: Gtk.Widget, event: Gdk.EventKey) -> None:
-        if event.keyval == Gdk.KEY_Escape:
-            self.destroy()
+    def _cleanup(self, *args: Any) -> None:
+        self.unregister_events()
 
     def _add_connection_info(self) -> None:
         # Connection type
         nbxmpp_client = self._client.connection
         address = nbxmpp_client.current_address
 
+        assert address is not None
         self._ui.connection_type.set_text(address.type.value)
         if address.type.is_plain:
-            self._ui.connection_type.get_style_context().add_class(
-                'error-color')
+            self._ui.connection_type.add_css_class("error-color")
 
         # Connection proxy
         proxy = address.proxy
@@ -131,33 +126,33 @@ class ServerInfo(Gtk.ApplicationWindow, EventHelper):
         visible = address.service is not None
         self._ui.dns_label.set_visible(visible)
         self._ui.dns.set_visible(visible)
-        self._ui.dns.set_text(address.service or '')
+        self._ui.dns.set_text(address.service or "")
 
         visible = nbxmpp_client.remote_address is not None
         self._ui.ip_port_label.set_visible(visible)
         self._ui.ip_port.set_visible(visible)
-        self._ui.ip_port.set_text(nbxmpp_client.remote_address or '')
+        self._ui.ip_port.set_text(nbxmpp_client.remote_address or "")
 
         visible = address.uri is not None
         self._ui.websocket_label.set_visible(visible)
         self._ui.websocket.set_visible(visible)
-        self._ui.websocket.set_text(address.uri or '')
+        self._ui.websocket.set_text(address.uri or "")
 
+        assert nbxmpp_client is not None
         tls_version = TLS_VERSION_STRINGS.get(nbxmpp_client.tls_version)
-        self._ui.tls_version.set_text(tls_version or _('Not available'))
+        self._ui.tls_version.set_text(tls_version or _("Not available"))
 
-        self._ui.cipher_suite.set_text(nbxmpp_client.ciphersuite or
-                                       _('Not available'))
+        self._ui.cipher_suite.set_text(nbxmpp_client.ciphersuite or _("Not available"))
 
-    def _add_contact_addresses(self, dataforms: list[SimpleDataForm]) -> None:
+    def _add_contact_addresses(self, dataforms: list[DataForm]) -> None:
         fields = {
-            'admin-addresses': _('Admin'),
-            'status-addresses': _('Status'),
-            'support-addresses': _('Support'),
-            'security-addresses': _('Security'),
-            'feedback-addresses': _('Feedback'),
-            'abuse-addresses': _('Abuse'),
-            'sales-addresses': _('Sales'),
+            "admin-addresses": _("Admin"),
+            "status-addresses": _("Status"),
+            "support-addresses": _("Support"),
+            "security-addresses": _("Security"),
+            "feedback-addresses": _("Feedback"),
+            "abuse-addresses": _("Abuse"),
+            "sales-addresses": _("Sales"),
         }
 
         addresses = self._get_addresses(fields, dataforms)
@@ -176,13 +171,13 @@ class ServerInfo(Gtk.ApplicationWindow, EventHelper):
                 row_count += 1
 
     @staticmethod
-    def _get_addresses(fields: dict[str, str],
-                       dataforms: list[SimpleDataForm]
-                       ) -> dict[str, list[str]] | None:
+    def _get_addresses(
+        fields: dict[str, str], dataforms: list[DataForm]
+    ) -> dict[str, list[str]] | None:
         addresses: dict[str, list[str]] = {}
         for form in dataforms:
-            field = form.vars.get('FORM_TYPE')
-            if field.value != 'http://jabber.org/network/serverinfo':
+            field = form.vars.get("FORM_TYPE")
+            if field.value != "http://jabber.org/network/serverinfo":
                 continue
 
             for address_type in fields:
@@ -190,7 +185,7 @@ class ServerInfo(Gtk.ApplicationWindow, EventHelper):
                 if field is None:
                     continue
 
-                if field.type_ != 'list-multi':
+                if field.type_ != "list-multi":
                     continue
 
                 if not field.values:
@@ -205,20 +200,17 @@ class ServerInfo(Gtk.ApplicationWindow, EventHelper):
         label = Gtk.Label(label=text)
         label.set_halign(Gtk.Align.END)
         label.set_valign(Gtk.Align.START)
-        label.get_style_context().add_class('dim-label')
+        label.add_css_class("dim-label")
         return label
 
-    def _get_address_label(self,
-                           address: str,
-                           last: bool = False
-                           ) -> Gtk.Label:
+    def _get_address_label(self, address: str, last: bool = False) -> Gtk.Label:
         label = Gtk.Label()
         label.set_markup(f'<a href="{address}">{address}</a>')
         label.set_ellipsize(Pango.EllipsizeMode.END)
         label.set_xalign(0)
         label.set_halign(Gtk.Align.START)
-        label.get_style_context().add_class('link-button')
-        label.connect('activate-link', self._on_activate_link)
+        label.add_css_class("link-button")
+        self._connect(label, "activate-link", self._on_activate_link)
         if last:
             label.set_margin_bottom(6)
         return label
@@ -238,96 +230,122 @@ class ServerInfo(Gtk.ApplicationWindow, EventHelper):
         hours = 0
         if result.seconds >= 3600:
             hours = delta.seconds // 3600
-        uptime = _('%(days)s days, %(hours)s hours') % {
-            'days': delta.days,
-            'hours': hours}
+        uptime = _("%(days)s days, %(hours)s hours") % {
+            "days": delta.days,
+            "hours": hours,
+        }
         self._ui.server_uptime.set_text(uptime)
 
     def _software_version_received(self, task: Task) -> None:
         try:
             result = cast(SoftwareVersionResult, task.finish())
         except StanzaError:
-            self._version = _('Unknown')
+            self._version = _("Unknown")
         else:
-            self._version = f'{result.name} {result.version}'
+            self._version = f"{result.name} {result.version}"
 
         self._ui.server_software.set_text(self._version)
 
     def _server_disco_received(self, _event: ServerDiscoReceived) -> None:
         features = self._get_features()
         for index, item in enumerate(features):
-            row = cast(
-                FeatureItem, self._ui.features_listbox.get_row_at_index(index))
+            row = cast(FeatureItem, self._ui.features_listbox.get_row_at_index(index))
             row.update(item)
 
     def _add_feature(self, feature: Feature) -> None:
         item = FeatureItem(feature)
-        self._ui.features_listbox.add(item)
+        self._ui.features_listbox.append(item)
 
     def _get_features(self) -> list[Feature]:
-        http_upload_module = self._client.get_module('HTTPUpload')
+        http_upload_module = self._client.get_module("HTTPUpload")
         http_upload_info = http_upload_module.httpupload_namespace
         if http_upload_module.available:
             max_size = http_upload_module.max_file_size
             if max_size is not None:
-                max_size = GLib.format_size_full(max_size, self._units)
-                http_upload_info = f'{http_upload_info} (max. {max_size})'
+                max_size = GLib.format_size_full(int(max_size), self._units)
+                http_upload_info = f"{http_upload_info} (max. {max_size})"
 
         return [
-            Feature('XEP-0045: Multi-User Chat',
-                    self._client.get_module('MUC').supported),
-            Feature('XEP-0054: vcard-temp',
-                    self._client.get_module('VCardTemp').supported),
-            Feature('XEP-0077: In-Band Registration',
-                    self._client.get_module('Register').supported),
-            Feature('XEP-0163: Personal Eventing Protocol',
-                    self._client.get_module('PEP').supported),
-            Feature('XEP-0163: #publish-options',
-                    self._client.get_module('PubSub').publish_options),
-            Feature('XEP-0191: Blocking Command',
-                    self._client.get_module('Blocking').supported,
-                    Namespace.BLOCKING),
-            Feature('XEP-0198: Stream Management',
-                    self._client.features.has_sm,
-                    Namespace.STREAM_MGMT),
-            Feature('XEP-0258: Security Labels in XMPP',
-                    self._client.get_module('SecLabels').supported,
-                    Namespace.SECLABEL),
-            Feature('XEP-0280: Message Carbons',
-                    self._client.get_module('Carbons').supported,
-                    Namespace.CARBONS),
-            Feature('XEP-0313: Message Archive Management',
-                    self._client.get_module('MAM').available),
-            Feature('XEP-0363: HTTP File Upload',
-                    self._client.get_module('HTTPUpload').available,
-                    http_upload_info),
-            Feature('XEP-0398: Avatar Conversion',
-                    self._client.get_module(
-                        'VCardAvatars').avatar_conversion_available),
-            Feature('XEP-0411: Bookmarks Conversion',
-                    self._client.get_module('Bookmarks').conversion),
-            Feature('XEP-0402: Bookmarks Compat',
-                    self._client.get_module('Bookmarks').compat),
-            Feature('XEP-0402: Bookmarks Compat PEP',
-                    self._client.get_module('Bookmarks').compat_pep)
+            Feature(
+                "XEP-0045: Multi-User Chat", self._client.get_module("MUC").supported
+            ),
+            Feature(
+                "XEP-0054: vcard-temp", self._client.get_module("VCardTemp").supported
+            ),
+            Feature(
+                "XEP-0077: In-Band Registration",
+                self._client.get_module("Register").supported,
+            ),
+            Feature(
+                "XEP-0163: Personal Eventing Protocol",
+                self._client.get_module("PEP").supported,
+            ),
+            Feature(
+                "XEP-0163: #publish-options",
+                self._client.get_module("PubSub").publish_options,
+            ),
+            Feature(
+                "XEP-0191: Blocking Command",
+                self._client.get_module("Blocking").supported,
+                Namespace.BLOCKING,
+            ),
+            Feature(
+                "XEP-0198: Stream Management",
+                self._client.features.has_sm(),
+                Namespace.STREAM_MGMT,
+            ),
+            Feature(
+                "XEP-0258: Security Labels in XMPP",
+                self._client.get_module("SecLabels").supported,
+                Namespace.SECLABEL,
+            ),
+            Feature(
+                "XEP-0280: Message Carbons",
+                self._client.get_module("Carbons").supported,
+                Namespace.CARBONS,
+            ),
+            Feature(
+                "XEP-0313: Message Archive Management",
+                self._client.get_module("MAM").available,
+            ),
+            Feature(
+                "XEP-0363: HTTP File Upload",
+                self._client.get_module("HTTPUpload").available,
+                http_upload_info,
+            ),
+            Feature(
+                "XEP-0398: Avatar Conversion",
+                self._client.get_module("VCardAvatars").avatar_conversion_available,
+            ),
+            Feature(
+                "XEP-0411: Bookmarks Conversion",
+                self._client.get_module("Bookmarks").conversion,
+            ),
+            Feature(
+                "XEP-0402: Bookmarks Compat",
+                self._client.get_module("Bookmarks").compat,
+            ),
+            Feature(
+                "XEP-0402: Bookmarks Compat PEP",
+                self._client.get_module("Bookmarks").compat_pep,
+            ),
         ]
 
     def _on_clipboard_button_clicked(self, _widget: Gtk.Button) -> None:
-        server_software = _('Server Software: %s\n') % self._version
-        server_features = ''
+        server_software = _("Server Software: %s\n") % self._version
+        server_features = ""
 
         for feature in self._get_features():
             if feature.available:
-                available = _('Available')
+                available = _("Available")
             else:
-                available = _('Not available')
-            additional = ''
+                available = _("Not available")
+            additional = ""
             if feature.additional is not None:
-                additional = f'({feature.additional})'
-            server_features += f'{feature.name}: {available} {additional}\n'
+                additional = f"({feature.additional})"
+            server_features += f"{feature.name}: {available} {additional}\n"
 
-        clipboard_text = server_software + server_features
-        self._clipboard.set_text(clipboard_text, -1)
+        self.window.get_clipboard().set(server_software + server_features)
 
 
 class FeatureItem(Gtk.ListBoxRow):
@@ -342,35 +360,31 @@ class FeatureItem(Gtk.ListBoxRow):
         self._feature_label.set_halign(Gtk.Align.START)
         self._additional_label = Gtk.Label()
         self._additional_label.set_halign(Gtk.Align.START)
-        self._additional_label.set_no_show_all(True)
-        self._additional_label.get_style_context().add_class('dim-label')
+        self._additional_label.set_visible(False)
+        self._additional_label.add_css_class("dim-label")
 
         grid.attach(self._icon, 0, 0, 1, 1)
         grid.attach(self._feature_label, 1, 0, 1, 1)
         grid.attach(self._additional_label, 1, 1, 1, 1)
 
         self._set_feature()
-
-        self.add(grid)
-        self.show_all()
+        self.set_child(grid)
 
     def _set_feature(self) -> None:
         self._feature_label.set_text(self._feature.name)
         if self._feature.additional is not None:
             self._additional_label.set_text(self._feature.additional)
-            self._additional_label.show()
+            self._additional_label.set_visible(True)
 
-        self._icon.get_style_context().remove_class('error-color')
-        self._icon.get_style_context().remove_class('success-color')
+        self._icon.remove_css_class("error-color")
+        self._icon.remove_css_class("success-color")
 
         if self._feature.available:
-            self._icon.set_from_icon_name(
-                'emblem-ok-symbolic', Gtk.IconSize.MENU)
-            self._icon.get_style_context().add_class('success-color')
+            self._icon.set_from_icon_name("feather-check-symbolic")
+            self._icon.add_css_class("success-color")
         else:
-            self._icon.set_from_icon_name(
-                'window-close-symbolic', Gtk.IconSize.MENU)
-            self._icon.get_style_context().add_class('error-color')
+            self._icon.set_from_icon_name("window-close-symbolic")
+            self._icon.add_css_class("error-color")
 
     def update(self, feature: Feature) -> None:
         self._feature = feature
