@@ -1,8 +1,12 @@
+# This file is part of Gajim.
+#
+# SPDX-License-Identifier: GPL-3.0-or-later
+
 from __future__ import annotations
 
 import unittest
 from datetime import datetime
-from datetime import timezone
+from datetime import UTC
 
 from nbxmpp.protocol import JID
 
@@ -23,30 +27,28 @@ class CorrectionsTest(unittest.TestCase):
         self._archive = MessageArchiveStorage(in_memory=True)
         self._archive.init()
 
-        self._account = 'testacc1'
-        self._account_jid = JID.from_string('user@domain.org')
-        self._remote_jid = JID.from_string('remote@jid.org')
-        self._occupant_id = 'occupantid1'
+        self._account = "testacc1"
+        self._account_jid = JID.from_string("user@domain.org")
+        self._remote_jid = JID.from_string("remote@jid.org")
+        self._occupant_id = "occupantid1"
         self._init_settings()
 
     def _init_settings(self) -> None:
         app.settings = Settings(in_memory=True)
         app.settings.init()
-        app.settings.add_account('testacc1')
-        app.settings.set_account_setting(
-            'testacc1', 'address', 'user@domain.org')
+        app.settings.add_account("testacc1")
+        app.settings.set_account_setting("testacc1", "address", "user@domain.org")
 
-        app.settings.add_account('testacc2')
-        app.settings.set_account_setting(
-            'testacc2', 'address', 'user2@domain.org')
+        app.settings.add_account("testacc2")
+        app.settings.set_account_setting("testacc2", "address", "user2@domain.org")
 
     def _create_base_occupant(self, occupant_id: str) -> Occupant:
         return Occupant(
             account_=self._account,
             remote_jid_=self._remote_jid,
             id=occupant_id,
-            nickname='peter',
-            updated_at=datetime.fromtimestamp(50, timezone.utc),
+            nickname="peter",
+            updated_at=datetime.fromtimestamp(50, UTC),
         )
 
     def _create_base_message(self) -> Message:
@@ -56,14 +58,14 @@ class CorrectionsTest(unittest.TestCase):
             type=MessageType.GROUPCHAT,
             direction=ChatDirection.INCOMING,
             state=MessageState.ACKNOWLEDGED,
-            timestamp=datetime.fromtimestamp(0, timezone.utc),
-            resource='res1',
-            text='Some Message',
-            id='messageid1',
+            timestamp=datetime.fromtimestamp(0, UTC),
+            resource="res1",
+            text="Some Message",
+            id="messageid1",
             stanza_id=get_uuid(),
             correction_id=None,
-            occupant_=self._create_base_occupant('occupantid1'),
-            oob=[OOB(url='https://www.test.com', description='desc')],
+            occupant_=self._create_base_occupant("occupantid1"),
+            oob=[OOB(url="https://www.test.com", description="desc")],
         )
 
     def test_join_correction_groupchat_occupant_id(self) -> None:
@@ -76,12 +78,12 @@ class CorrectionsTest(unittest.TestCase):
         # Insert in not ascending order to test ordering
 
         m = self._create_base_message()
-        m.text = 'second correction'
-        m.id = 'messageid3'
-        m.timestamp = datetime.fromtimestamp(2, timezone.utc)
-        m.correction_id = 'messageid1'
+        m.text = "second correction"
+        m.id = "messageid3"
+        m.timestamp = datetime.fromtimestamp(2, UTC)
+        m.correction_id = "messageid1"
         assert m.oob
-        m.oob[0].description = 'second corrected desc'
+        m.oob[0].description = "second corrected desc"
 
         self._archive.insert_object(m)
 
@@ -89,22 +91,22 @@ class CorrectionsTest(unittest.TestCase):
         # this message should be still joined
 
         m = self._create_base_message()
-        m.text = 'first correction'
-        m.resource = 'otherres'
-        m.id = 'messageid2'
-        m.timestamp = datetime.fromtimestamp(1, timezone.utc)
-        m.correction_id = 'messageid1'
+        m.text = "first correction"
+        m.resource = "otherres"
+        m.id = "messageid2"
+        m.timestamp = datetime.fromtimestamp(1, UTC)
+        m.correction_id = "messageid1"
 
         self._archive.insert_object(m)
 
         # Add correction from unrelated occupant, should not be joined
 
         m = self._create_base_message()
-        m.occupant_ = self._create_base_occupant('occupantid2')
-        m.text = 'third correction'
-        m.id = 'messageid4'
-        m.timestamp = datetime.fromtimestamp(3, timezone.utc)
-        m.correction_id = 'messageid1'
+        m.occupant_ = self._create_base_occupant("occupantid2")
+        m.text = "third correction"
+        m.id = "messageid4"
+        m.timestamp = datetime.fromtimestamp(3, UTC)
+        m.correction_id = "messageid1"
 
         self._archive.insert_object(m)
 
@@ -112,10 +114,10 @@ class CorrectionsTest(unittest.TestCase):
 
         m = self._create_base_message()
         m.occupant_ = None
-        m.text = 'third correction'
-        m.id = 'messageid5'
-        m.timestamp = datetime.fromtimestamp(4, timezone.utc)
-        m.correction_id = 'messageid1'
+        m.text = "third correction"
+        m.id = "messageid5"
+        m.timestamp = datetime.fromtimestamp(4, UTC)
+        m.correction_id = "messageid1"
 
         self._archive.insert_object(m)
 
@@ -125,11 +127,11 @@ class CorrectionsTest(unittest.TestCase):
         assert message.corrections
 
         self.assertEqual(len(message.corrections), 2)
-        self.assertEqual(message.corrections[0].text, 'first correction')
-        self.assertEqual(message.corrections[1].text, 'second correction')
+        self.assertEqual(message.corrections[0].text, "first correction")
+        self.assertEqual(message.corrections[1].text, "second correction")
         assert message.corrections[1].oob is not None
         self.assertEqual(
-            message.corrections[1].oob[0].description, 'second corrected desc'
+            message.corrections[1].oob[0].description, "second corrected desc"
         )
 
     def test_join_correction_groupchat_resource(self) -> None:
@@ -141,10 +143,10 @@ class CorrectionsTest(unittest.TestCase):
 
         m = self._create_base_message()
         m.occupant_ = None
-        m.text = 'first correction'
-        m.id = 'messageid2'
-        m.timestamp = datetime.fromtimestamp(1, timezone.utc)
-        m.correction_id = 'messageid1'
+        m.text = "first correction"
+        m.id = "messageid2"
+        m.timestamp = datetime.fromtimestamp(1, UTC)
+        m.correction_id = "messageid1"
 
         self._archive.insert_object(m)
 
@@ -152,11 +154,11 @@ class CorrectionsTest(unittest.TestCase):
 
         m = self._create_base_message()
         m.occupant_ = None
-        m.resource = 'unrelatedres'
-        m.text = 'second correction'
-        m.id = 'messageid3'
-        m.timestamp = datetime.fromtimestamp(2, timezone.utc)
-        m.correction_id = 'messageid1'
+        m.resource = "unrelatedres"
+        m.text = "second correction"
+        m.id = "messageid3"
+        m.timestamp = datetime.fromtimestamp(2, UTC)
+        m.correction_id = "messageid1"
 
         self._archive.insert_object(m)
 
@@ -166,7 +168,7 @@ class CorrectionsTest(unittest.TestCase):
         assert message.corrections
 
         self.assertEqual(len(message.corrections), 1)
-        self.assertEqual(message.corrections[0].text, 'first correction')
+        self.assertEqual(message.corrections[0].text, "first correction")
 
     def test_join_correction_single_chat(self) -> None:
         # Order corrections by timestamp
@@ -178,10 +180,10 @@ class CorrectionsTest(unittest.TestCase):
 
         m = self._create_base_message()
         m.type = MessageType.CHAT
-        m.text = 'first correction'
-        m.id = 'messageid2'
-        m.timestamp = datetime.fromtimestamp(1, timezone.utc)
-        m.correction_id = 'messageid1'
+        m.text = "first correction"
+        m.id = "messageid2"
+        m.timestamp = datetime.fromtimestamp(1, UTC)
+        m.correction_id = "messageid1"
 
         self._archive.insert_object(m)
 
@@ -190,11 +192,11 @@ class CorrectionsTest(unittest.TestCase):
 
         m = self._create_base_message()
         m.type = MessageType.CHAT
-        m.text = 'second correction'
-        m.resource = 'otherres'
-        m.id = 'messageid3'
-        m.timestamp = datetime.fromtimestamp(2, timezone.utc)
-        m.correction_id = 'messageid1'
+        m.text = "second correction"
+        m.resource = "otherres"
+        m.id = "messageid3"
+        m.timestamp = datetime.fromtimestamp(2, UTC)
+        m.correction_id = "messageid1"
 
         self._archive.insert_object(m)
 
@@ -202,11 +204,11 @@ class CorrectionsTest(unittest.TestCase):
 
         m = self._create_base_message()
         m.type = MessageType.CHAT
-        m.remote_jid_ = JID.from_string('other@remote.jid')
-        m.text = 'third correction'
-        m.id = 'messageid4'
-        m.timestamp = datetime.fromtimestamp(3, timezone.utc)
-        m.correction_id = 'messageid1'
+        m.remote_jid_ = JID.from_string("other@remote.jid")
+        m.text = "third correction"
+        m.id = "messageid4"
+        m.timestamp = datetime.fromtimestamp(3, UTC)
+        m.correction_id = "messageid1"
 
         self._archive.insert_object(m)
 
@@ -214,11 +216,11 @@ class CorrectionsTest(unittest.TestCase):
 
         m = self._create_base_message()
         m.type = MessageType.CHAT
-        m.account_ = 'testacc2'
-        m.text = 'fourth correction'
-        m.id = 'messageid5'
-        m.timestamp = datetime.fromtimestamp(4, timezone.utc)
-        m.correction_id = 'messageid1'
+        m.account_ = "testacc2"
+        m.text = "fourth correction"
+        m.id = "messageid5"
+        m.timestamp = datetime.fromtimestamp(4, UTC)
+        m.correction_id = "messageid1"
 
         self._archive.insert_object(m)
 
@@ -227,10 +229,10 @@ class CorrectionsTest(unittest.TestCase):
         m = self._create_base_message()
         m.type = MessageType.CHAT
         m.direction = ChatDirection.OUTGOING
-        m.text = 'fifth correction'
-        m.id = 'messageid6'
-        m.timestamp = datetime.fromtimestamp(5, timezone.utc)
-        m.correction_id = 'messageid1'
+        m.text = "fifth correction"
+        m.id = "messageid6"
+        m.timestamp = datetime.fromtimestamp(5, UTC)
+        m.correction_id = "messageid1"
 
         self._archive.insert_object(m)
 
@@ -240,9 +242,9 @@ class CorrectionsTest(unittest.TestCase):
         assert message.corrections
 
         self.assertEqual(len(message.corrections), 2)
-        self.assertEqual(message.corrections[0].text, 'first correction')
-        self.assertEqual(message.corrections[1].text, 'second correction')
+        self.assertEqual(message.corrections[0].text, "first correction")
+        self.assertEqual(message.corrections[1].text, "second correction")
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     unittest.main()
