@@ -1,8 +1,12 @@
+# This file is part of Gajim.
+#
+# SPDX-License-Identifier: GPL-3.0-or-later
+
 from __future__ import annotations
 
 import unittest
 from datetime import datetime
-from datetime import timezone
+from datetime import UTC
 
 from nbxmpp.protocol import JID
 from sqlalchemy import select
@@ -28,51 +32,50 @@ class ForeignKeyTest(unittest.TestCase):
         self._archive = MessageArchiveStorage(in_memory=True)
         self._archive.init()
 
-        self._account = 'testacc1'
-        self._account_jid = JID.from_string('user@domain.org')
-        self._remote_jid = JID.from_string('remote@jid.org')
-        self._occupant_id = 'occupantid1'
+        self._account = "testacc1"
+        self._account_jid = JID.from_string("user@domain.org")
+        self._remote_jid = JID.from_string("remote@jid.org")
+        self._occupant_id = "occupantid1"
         self._init_settings()
 
     def _init_settings(self) -> None:
         app.settings = Settings(in_memory=True)
         app.settings.init()
-        app.settings.add_account('testacc1')
-        app.settings.set_account_setting(
-            'testacc1', 'address', 'user@domain.org')
+        app.settings.add_account("testacc1")
+        app.settings.set_account_setting("testacc1", "address", "user@domain.org")
 
     def test_message_delete_cascade(self) -> None:
-        oob_data1 = OOB(url='https://www.test.com', description='somedesc')
-        oob_data2 = OOB(url='https://www.othertest.com', description='otherdesc')
+        oob_data1 = OOB(url="https://www.test.com", description="somedesc")
+        oob_data2 = OOB(url="https://www.othertest.com", description="otherdesc")
 
         reply_data = Reply(
-            id='123',
-            to=JID.from_string('somejid@jid.com'),
+            id="123",
+            to=JID.from_string("somejid@jid.com"),
         )
 
-        enc_data = Encryption(protocol=1, key='testkey', trust=2)
+        enc_data = Encryption(protocol=1, key="testkey", trust=2)
 
         sec_data = SecurityLabel(
             account_=self._account,
             remote_jid_=self._remote_jid,
-            updated_at=datetime.fromtimestamp(0, timezone.utc),
-            label_hash='somehash',
-            displaymarking='SECRET',
-            fgcolor='black',
-            bgcolor='red',
+            updated_at=datetime.fromtimestamp(0, UTC),
+            label_hash="somehash",
+            displaymarking="SECRET",
+            fgcolor="black",
+            bgcolor="red",
         )
 
         message_data = Message(
             account_=self._account,
             remote_jid_=self._remote_jid,
-            resource='someres1',
+            resource="someres1",
             type=MessageType.CHAT,
             direction=ChatDirection.INCOMING,
-            timestamp=datetime.now(timezone.utc),
+            timestamp=datetime.now(UTC),
             state=MessageState.ACKNOWLEDGED,
-            id='1',
+            id="1",
             stanza_id=get_uuid(),
-            text='message',
+            text="message",
             encryption_=enc_data,
             security_label_=sec_data,
             oob=[oob_data1, oob_data2],
@@ -84,12 +87,12 @@ class ForeignKeyTest(unittest.TestCase):
         error_data = MessageError(
             account_=self._account,
             remote_jid_=self._remote_jid,
-            message_id='1',
-            by=JID.from_string('some@jid.com'),
-            type='modify',
-            text='Some error text',
-            condition='not-acceptable',
-            condition_text='Some Application Text',
+            message_id="1",
+            by=JID.from_string("some@jid.com"),
+            type="modify",
+            text="Some error text",
+            condition="not-acceptable",
+            condition_text="Some Application Text",
             timestamp=utc_now(),
         )
 
@@ -99,30 +102,30 @@ class ForeignKeyTest(unittest.TestCase):
 
         assert message is not None
         assert message.oob is not None
-        self.assertEqual(message.oob[0].description, 'somedesc')
-        self.assertEqual(message.oob[1].description, 'otherdesc')
+        self.assertEqual(message.oob[0].description, "somedesc")
+        self.assertEqual(message.oob[1].description, "otherdesc")
 
         assert message.reply is not None
-        self.assertEqual(message.reply.id, '123')
-        self.assertEqual(message.reply.to, JID.from_string('somejid@jid.com'))
+        self.assertEqual(message.reply.id, "123")
+        self.assertEqual(message.reply.to, JID.from_string("somejid@jid.com"))
         self.assertIsInstance(message.reply.to, JID)
 
         self.assertEqual(message.account.jid, self._account_jid)
         self.assertEqual(message.remote.jid, self._remote_jid)
 
         assert message.encryption is not None
-        self.assertEqual(message.encryption.key, 'testkey')
+        self.assertEqual(message.encryption.key, "testkey")
 
         assert message.security_label is not None
-        self.assertEqual(message.security_label.displaymarking, 'SECRET')
+        self.assertEqual(message.security_label.displaymarking, "SECRET")
 
         assert message.error is not None
-        self.assertEqual(message.error.by, 'some@jid.com')
+        self.assertEqual(message.error.by, "some@jid.com")
         self.assertIsInstance(message.error.by, JID)
-        self.assertEqual(message.error.text, 'Some error text')
-        self.assertEqual(message.error.condition, 'not-acceptable')
-        self.assertEqual(message.error.condition_text, 'Some Application Text')
-        self.assertEqual(message.error.type, 'modify')
+        self.assertEqual(message.error.text, "Some error text")
+        self.assertEqual(message.error.condition, "not-acceptable")
+        self.assertEqual(message.error.condition_text, "Some Application Text")
+        self.assertEqual(message.error.type, "modify")
 
         self._archive.delete_message(message.pk)
 
@@ -138,5 +141,5 @@ class ForeignKeyTest(unittest.TestCase):
             assert res is None
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     unittest.main()
