@@ -112,10 +112,10 @@ qrcode
 css_parser
 sentry-sdk
 emoji
-winrt-Windows.ApplicationModel
-winrt-Windows.Foundation
-winrt-Windows.UI
-winrt-Windows.UI.ViewManagement
+winrt-Windows.ApplicationModel==2.3.0
+winrt-Windows.Foundation==2.3.0
+winrt-Windows.UI==2.3.0
+winrt-Windows.UI.ViewManagement==2.3.0
 windows-toasts
 "
     build_pip install precis-i18n
